@@ -1,11 +1,11 @@
 #include "sim800l.h"
 #include "esphome/core/log.h"
-#include <string.h>
+#include <cstring>
 
 namespace esphome {
 namespace sim800l {
 
-static const char* TAG = "sim800l";
+static const char *const TAG = "sim800l";
 
 const char ASCII_CR = 0x0D;
 const char ASCII_LF = 0x0A;
@@ -20,6 +20,9 @@ void Sim800LComponent::update() {
     if (this->registered_ && this->send_pending_) {
       this->send_cmd_("AT+CSCS=\"GSM\"");
       this->state_ = STATE_SENDINGSMS1;
+    } else if (this->registered_ && this->dial_pending_) {
+      this->send_cmd_("AT+CSCS=\"GSM\"");
+      this->state_ = STATE_DIALING1;
     } else {
       this->send_cmd_("AT");
       this->state_ = STATE_CHECK_AT;
@@ -37,7 +40,7 @@ void Sim800LComponent::update() {
   }
 }
 
-void Sim800LComponent::send_cmd_(std::string message) {
+void Sim800LComponent::send_cmd_(const std::string &message) {
   ESP_LOGV(TAG, "S: %s - %d", message.c_str(), this->state_);
   this->watch_dog_ = 0;
   this->write_str(message.c_str());
@@ -97,7 +100,7 @@ void Sim800LComponent::parse_cmd_(std::string message) {
     case STATE_CREGWAIT: {
       // Response: "+CREG: 0,1" -- the one there means registered ok
       //           "+CREG: -,-" means not registered ok
-      bool registered = message.compare(0, 6, "+CREG:") == 0 && message[9] == '1';
+      bool registered = message.compare(0, 6, "+CREG:") == 0 && (message[9] == '1' || message[9] == '5');
       if (registered) {
         if (!this->registered_)
           ESP_LOGD(TAG, "Registered OK");
@@ -125,7 +128,7 @@ void Sim800LComponent::parse_cmd_(std::string message) {
       if (message.compare(0, 5, "+CSQ:") == 0) {
         size_t comma = message.find(',', 6);
         if (comma != 6) {
-          this->rssi_ = strtol(message.substr(6, comma - 6).c_str(), nullptr, 10);
+          this->rssi_ = parse_number<int>(message.substr(6, comma - 6)).value_or(0);
           ESP_LOGD(TAG, "RSSI: %d", this->rssi_);
         }
       }
@@ -143,7 +146,7 @@ void Sim800LComponent::parse_cmd_(std::string message) {
         while (end != start) {
           item++;
           if (item == 1) {  // Slot Index
-            this->parse_index_ = strtol(message.substr(start, end - start).c_str(), nullptr, 10);
+            this->parse_index_ = parse_number<uint8_t>(message.substr(start, end - start)).value_or(0);
           }
           // item 2 = STATUS, usually "REC UNERAD"
           if (item == 3) {  // recipient
@@ -212,6 +215,23 @@ void Sim800LComponent::parse_cmd_(std::string message) {
         this->expect_ack_ = true;
       }
       break;
+    case STATE_DIALING1:
+      this->send_cmd_("ATD" + this->recipient_ + ';');
+      this->state_ = STATE_DIALING2;
+      break;
+    case STATE_DIALING2:
+      if (message == "OK") {
+        // Dialing
+        ESP_LOGD(TAG, "Dialing: '%s'", this->recipient_.c_str());
+        this->state_ = STATE_INIT;
+        this->dial_pending_ = false;
+      } else {
+        this->registered_ = false;
+        this->state_ = STATE_INIT;
+        this->send_cmd_("AT+CMEE=2");
+        this->write(26);
+      }
+      break;
     default:
       ESP_LOGD(TAG, "Unhandled: %s - %d", message.c_str(), this->state_);
       break;
@@ -248,7 +268,7 @@ void Sim800LComponent::loop() {
   }
 }
 
-void Sim800LComponent::send_sms(std::string recipient, std::string message) {
+void Sim800LComponent::send_sms(const std::string &recipient, const std::string &message) {
   ESP_LOGD(TAG, "Sending to %s: %s", recipient.c_str(), message.c_str());
   this->recipient_ = recipient;
   this->outgoing_message_ = message;
@@ -259,6 +279,12 @@ void Sim800LComponent::dump_config() {
   ESP_LOGCONFIG(TAG, "SIM800L:");
   ESP_LOGCONFIG(TAG, "  RSSI: %d dB", this->rssi_);
 }
+void Sim800LComponent::dial(const std::string &recipient) {
+  ESP_LOGD(TAG, "Dialing %s", recipient.c_str());
+  this->recipient_ = recipient;
+  this->dial_pending_ = true;
+  this->update();
+}
 
 }  // namespace sim800l
 }  // namespace esphome
